package de.unikoblenz.fgbks.base.utils.boundary.checker;

import de.unikoblenz.fgbks.base.utils.boundary.impl.StringBoundary;

public class CheckStringEqual extends AbstractBoundaryCheck<StringBoundary> {

  private static CheckStringEqual instance = new CheckStringEqual();

  public static CheckStringEqual getInstance() {
    return instance;
  }

  @Override
  public BoundaryCheckType getType() {
    return BoundaryCheckType.IS_EQUAL;
  }

  @Override
  public boolean check(StringBoundary b1, StringBoundary b2) {
    return checkEqual(b1, b2);
  }

  public static boolean checkEqual(StringBoundary b1, StringBoundary b2) {
    if (b1 == b2 || b1.getText().equals(b2.getText()) || b1.isMatchAny() && b2.isMatchAny()) {
      return true;
    }
    if (b1.isMatchNoneOfValues() != b2.isMatchNoneOfValues()
        || b1.getAmountOfElements() != b2.getAmountOfElements()) {
      return false;
    }
    // hashes are sorted while boundary creation
    int[] h1 = b1.getValuesHashes();
    int[] h2 = b2.getValuesHashes();
    for (int i = 0; i < h1.length; i++) {
      if (h1[i] != h2[i]) {
        return false;
      }
    }
    return true;
  }
}
